package com.jjt.wkEmp.service;

import java.util.List;
import com.jjt.wkEmp.domain.TwinWkEmpSync;

/**
 * 经编车间排班同步记录Service接口
 *
 * @author wukai
 * @date 2025-04-28
 */
public interface ITwinWkEmpSyncService {
    /**
     * 查询经编车间排班同步记录
     *
     * @param syncId 经编车间排班同步记录主键
     * @return 经编车间排班同步记录
     */
    public TwinWkEmpSync selectTwinWkEmpSyncBySyncId(Long syncId);

    /**
     * 查询经编车间排班同步记录列表
     *
     * @param twinWkEmpSync 经编车间排班同步记录
     * @return 经编车间排班同步记录集合
     */
    public List<TwinWkEmpSync> selectTwinWkEmpSyncList(TwinWkEmpSync twinWkEmpSync);

    /**
     * 新增经编车间排班同步记录
     *
     * @param twinWkEmpSync 经编车间排班同步记录
     * @return 结果
     */
    public int insertTwinWkEmpSync(TwinWkEmpSync twinWkEmpSync);

    /**
     * 修改经编车间排班同步记录
     *
     * @param twinWkEmpSync 经编车间排班同步记录
     * @return 结果
     */
    public int updateTwinWkEmpSync(TwinWkEmpSync twinWkEmpSync);

    /**
     * 批量删除经编车间排班同步记录
     *
     * @param syncIds 需要删除的经编车间排班同步记录主键集合
     * @return 结果
     */
    public int deleteTwinWkEmpSyncBySyncIds(Long[] syncIds);

    /**
     * 删除经编车间排班同步记录信息
     *
     * @param syncId 经编车间排班同步记录主键
     * @return 结果
     */
    public int deleteTwinWkEmpSyncBySyncId(Long syncId);

    /**
     * 清空记录
     * @return 结果
     */
    void clean();
}
